<?php

namespace Drupal\samlauth_group\Form;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\samlauth_group\EventSubscriber\SamlauthGroupSubscriber;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for deleting a mapping.
 */
class SamlauthGroupMembershipMappingDeleteForm extends ConfirmFormBase {

  /**
   * The name of the attribute we're deleting (needed for the confirm message).
   *
   * @var string
   */
  protected $attributeName;

  /**
   * The group id we're deleting (needed for the confirm message).
   *
   * @var string
   */
  protected $groupId;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'samlauth_group_membership_delete_form';
  }

  /**
   * Form for deleting a mapping.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param int $mapping_id
   *   (optional) The numeric ID of the mapping.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $mapping_id = NULL) {
    if ($mapping_id !== NULL) {
      $mappings = $this->configFactory()->getEditable(SamlauthGroupSubscriber::CONFIG_OBJECT_NAME)->get('membership_mappings');

      // Set these values for the confirm message to pick up on them.
      $this->attributeName = $mappings[$mapping_id]['attribute_name'];

      // Set the group id.
      $this->groupId = $mappings[$mapping_id]['group_id'];

      // Set the mapping id so the submit handler can delete it.
      $form_state->set('mapping_id', $mapping_id);

      return parent::buildForm($form, $form_state);
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the group membership mapping for %attribute to group %group ?', [
      '%attribute' => $this->attributeName,
      '%group' => $this->groupId,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('samlauth_group.membership_list');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable(SamlauthGroupSubscriber::CONFIG_OBJECT_NAME);
    $mappings = $config->get('membership_mappings');
    unset($mappings[$form_state->get('mapping_id')]);
    $config->set('membership_mappings', $mappings)->save();
    $this->messenger()->addMessage($this->t('The group membership mapping has been deleted.'));
    $form_state->setRedirect('samlauth_group.membership_list');
  }

}
